@@ -1,6 +1,10 @@
-#include "catch.hpp"
 
 #include <osmium/geom/geos.hpp>
+
+#ifdef OSMIUM_WITH_GEOS
+
+#include "catch.hpp"
+
 #include <osmium/geom/mercator_projection.hpp>
 
 #include "area_helper.hpp"
@@ -9,7 +13,7 @@
 TEST_CASE("GEOS geometry factory - create point") {
     osmium::geom::GEOSFactory<> factory;
 
-    std::unique_ptr<geos::geom::Point> point {factory.create_point(osmium::Location(3.2, 4.2))};
+    const std::unique_ptr<geos::geom::Point> point{factory.create_point(osmium::Location{3.2, 4.2})};
     REQUIRE(3.2 == point->getX());
     REQUIRE(4.2 == point->getY());
     REQUIRE(4326 == point->getSRID());
@@ -18,7 +22,7 @@ TEST_CASE("GEOS geometry factory - create point") {
 TEST_CASE("GEOS geometry factory - create point in web mercator") {
     osmium::geom::GEOSFactory<osmium::geom::MercatorProjection> factory;
 
-    std::unique_ptr<geos::geom::Point> point {factory.create_point(osmium::Location(3.2, 4.2))};
+    const std::unique_ptr<geos::geom::Point> point{factory.create_point(osmium::Location{3.2, 4.2})};
     REQUIRE(Approx(356222.3705384755l) == point->getX());
     REQUIRE(Approx(467961.143605213l) == point->getY());
     REQUIRE(3857 == point->getSRID());
@@ -26,9 +30,9 @@ TEST_CASE("GEOS geometry factory - create point in web mercator") {
 
 TEST_CASE("GEOS geometry factory - create point with externally created GEOS factory") {
     geos::geom::GeometryFactory geos_factory;
-    osmium::geom::GEOSFactory<> factory(geos_factory);
+    osmium::geom::GEOSFactory<> factory{geos_factory};
 
-    std::unique_ptr<geos::geom::Point> point {factory.create_point(osmium::Location(3.2, 4.2))};
+    const std::unique_ptr<geos::geom::Point> point{factory.create_point(osmium::Location{3.2, 4.2})};
     REQUIRE(3.2 == point->getX());
     REQUIRE(4.2 == point->getY());
     REQUIRE(0 == point->getSRID());
@@ -37,45 +41,45 @@ TEST_CASE("GEOS geometry factory - create point with externally created GEOS fac
 TEST_CASE("GEOS geometry factory - can not create from invalid location") {
     osmium::geom::GEOSFactory<> factory;
 
-    REQUIRE_THROWS_AS(factory.create_point(osmium::Location()), osmium::invalid_location);
+    REQUIRE_THROWS_AS(factory.create_point(osmium::Location{}), osmium::invalid_location);
 }
 
 TEST_CASE("GEOS geometry factory - create linestring") {
     osmium::geom::GEOSFactory<> factory;
 
-    osmium::memory::Buffer buffer(10000);
-    auto &wnl = create_test_wnl_okay(buffer);
+    osmium::memory::Buffer buffer{10000};
+    const auto& wnl = create_test_wnl_okay(buffer);
 
     SECTION("from way node list") {
-        std::unique_ptr<geos::geom::LineString> linestring {factory.create_linestring(wnl)};
+        const std::unique_ptr<geos::geom::LineString> linestring{factory.create_linestring(wnl)};
         REQUIRE(3 == linestring->getNumPoints());
 
-        std::unique_ptr<geos::geom::Point> p0 = std::unique_ptr<geos::geom::Point>(linestring->getPointN(0));
+        const auto p0 = std::unique_ptr<geos::geom::Point>(linestring->getPointN(0));
         REQUIRE(3.2 == p0->getX());
-        std::unique_ptr<geos::geom::Point> p2 = std::unique_ptr<geos::geom::Point>(linestring->getPointN(2));
+        const auto p2 = std::unique_ptr<geos::geom::Point>(linestring->getPointN(2));
         REQUIRE(3.6 == p2->getX());
     }
 
     SECTION("without duplicates and backwards") {
-        std::unique_ptr<geos::geom::LineString> linestring {factory.create_linestring(wnl, osmium::geom::use_nodes::unique, osmium::geom::direction::backward)};
+        const std::unique_ptr<geos::geom::LineString> linestring{factory.create_linestring(wnl, osmium::geom::use_nodes::unique, osmium::geom::direction::backward)};
         REQUIRE(3 == linestring->getNumPoints());
-        std::unique_ptr<geos::geom::Point> p0 = std::unique_ptr<geos::geom::Point>(linestring->getPointN(0));
+        const auto p0 = std::unique_ptr<geos::geom::Point>(linestring->getPointN(0));
         REQUIRE(3.6 == p0->getX());
-        std::unique_ptr<geos::geom::Point> p2 = std::unique_ptr<geos::geom::Point>(linestring->getPointN(2));
+        const auto p2 = std::unique_ptr<geos::geom::Point>(linestring->getPointN(2));
         REQUIRE(3.2 == p2->getX());
     }
 
     SECTION("with duplicates") {
-        std::unique_ptr<geos::geom::LineString> linestring {factory.create_linestring(wnl, osmium::geom::use_nodes::all)};
+        const std::unique_ptr<geos::geom::LineString> linestring{factory.create_linestring(wnl, osmium::geom::use_nodes::all)};
         REQUIRE(4 == linestring->getNumPoints());
-        std::unique_ptr<geos::geom::Point> p0 = std::unique_ptr<geos::geom::Point>(linestring->getPointN(0));
+        const auto p0 = std::unique_ptr<geos::geom::Point>(linestring->getPointN(0));
         REQUIRE(3.2 == p0->getX());
     }
 
     SECTION("with duplicates and backwards") {
-        std::unique_ptr<geos::geom::LineString> linestring {factory.create_linestring(wnl, osmium::geom::use_nodes::all, osmium::geom::direction::backward)};
+        const std::unique_ptr<geos::geom::LineString> linestring{factory.create_linestring(wnl, osmium::geom::use_nodes::all, osmium::geom::direction::backward)};
         REQUIRE(4 == linestring->getNumPoints());
-        std::unique_ptr<geos::geom::Point> p0 = std::unique_ptr<geos::geom::Point>(linestring->getPointN(0));
+        const auto p0 = std::unique_ptr<geos::geom::Point>(linestring->getPointN(0));
         REQUIRE(3.6 == p0->getX());
     }
 }
@@ -83,10 +87,10 @@ TEST_CASE("GEOS geometry factory - create linestring") {
 TEST_CASE("GEOS geometry factory - create area with one outer and no inner rings") {
     osmium::geom::GEOSFactory<> factory;
 
-    osmium::memory::Buffer buffer(10000);
+    osmium::memory::Buffer buffer{10000};
     const osmium::Area& area = create_test_area_1outer_0inner(buffer);
 
-    std::unique_ptr<geos::geom::MultiPolygon> mp {factory.create_multipolygon(area)};
+    const std::unique_ptr<geos::geom::MultiPolygon> mp{factory.create_multipolygon(area)};
     REQUIRE(1 == mp->getNumGeometries());
 
     const geos::geom::Polygon* p0 = dynamic_cast<const geos::geom::Polygon*>(mp->getGeometryN(0));
@@ -96,17 +100,17 @@ TEST_CASE("GEOS geometry factory - create area with one outer and no inner rings
     const geos::geom::LineString* l0e = p0->getExteriorRing();
     REQUIRE(4 == l0e->getNumPoints());
 
-    std::unique_ptr<geos::geom::Point> l0e_p0 = std::unique_ptr<geos::geom::Point>(l0e->getPointN(1));
+    const auto l0e_p0 = std::unique_ptr<geos::geom::Point>(l0e->getPointN(1));
     REQUIRE(3.5 == l0e_p0->getX());
 }
 
 TEST_CASE("GEOS geometry factory - create area with one outer and one inner ring") {
     osmium::geom::GEOSFactory<> factory;
 
-    osmium::memory::Buffer buffer(10000);
+    osmium::memory::Buffer buffer{10000};
     const osmium::Area& area = create_test_area_1outer_1inner(buffer);
 
-    std::unique_ptr<geos::geom::MultiPolygon> mp {factory.create_multipolygon(area)};
+    const std::unique_ptr<geos::geom::MultiPolygon> mp{factory.create_multipolygon(area)};
     REQUIRE(1 == mp->getNumGeometries());
 
     const geos::geom::Polygon* p0 = dynamic_cast<const geos::geom::Polygon*>(mp->getGeometryN(0));
@@ -123,10 +127,10 @@ TEST_CASE("GEOS geometry factory - create area with one outer and one inner ring
 TEST_CASE("GEOS geometry factory - create area with two outer and two inner rings") {
     osmium::geom::GEOSFactory<> factory;
 
-    osmium::memory::Buffer buffer(10000);
+    osmium::memory::Buffer buffer{10000};
     const osmium::Area& area = create_test_area_2outer_2inner(buffer);
 
-    std::unique_ptr<geos::geom::MultiPolygon> mp {factory.create_multipolygon(area)};
+    const std::unique_ptr<geos::geom::MultiPolygon> mp{factory.create_multipolygon(area)};
     REQUIRE(2 == mp->getNumGeometries());
 
     const geos::geom::Polygon* p0 = dynamic_cast<const geos::geom::Polygon*>(mp->getGeometryN(0));
@@ -144,3 +148,5 @@ TEST_CASE("GEOS geometry factory - create area with two outer and two inner ring
     REQUIRE(5 == l1e->getNumPoints());
 }
 
+#endif
+
